@@ -40,13 +40,13 @@ RigidBodyGraphicsItem::RigidBodyGraphicsItem(StepCore::Item* item, WorldModel* w
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
     _velocityHandler = new ArrowHandlerGraphicsItem(item, worldModel, this,
-                   _item->metaObject()->property("velocity"));
+                   _item->metaObject()->property(QStringLiteral("velocity")));
     _velocityHandler->setVisible(false);
 
     _angularVelocityHandler = new CircularArrowHandlerGraphicsItem(item, worldModel, this,
-                   ANGULAR_VELOCITY_RADIUS, _item->metaObject()->property("angularVelocity"));
+                   ANGULAR_VELOCITY_RADIUS, _item->metaObject()->property(QStringLiteral("angularVelocity")));
     _angleHandler = new CircularArrowHandlerGraphicsItem(item, worldModel, this,
-                   ANGLE_HANDLER_RADIUS, _item->metaObject()->property("angle"));
+                   ANGLE_HANDLER_RADIUS, _item->metaObject()->property(QStringLiteral("angle")));
     _angularVelocityHandler->setVisible(false);
     _angleHandler->setVisible(false);
     setOnHoverHandlerEnabled(true);
@@ -170,8 +170,8 @@ bool DiskCreator::sceneEvent(QEvent* event)
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
         _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
-        _worldModel->setProperty(_item, "position", vpos);
-        _worldModel->setProperty(_item, "radius", QVariant::fromValue(0.0));
+        _worldModel->setProperty(_item, QStringLiteral("position"), vpos);
+        _worldModel->setProperty(_item, QStringLiteral("radius"), QVariant::fromValue(0.0));
         _worldModel->addItem(_item);
         _worldModel->selectionModel()->setCurrentIndex(_worldModel->objectIndex(_item),
                                                     QItemSelectionModel::ClearAndSelect);
@@ -186,7 +186,7 @@ bool DiskCreator::sceneEvent(QEvent* event)
         _worldModel->simulationPause();
         StepCore::Vector2d pos = StepGraphicsItem::pointToVector(mouseEvent->scenePos());
         double radius = (pos - static_cast<StepCore::Disk*>(_item)->position()).norm();
-        _worldModel->setProperty(_item, "radius", QVariant::fromValue(radius));
+        _worldModel->setProperty(_item, QStringLiteral("radius"), QVariant::fromValue(radius));
         return true;
 
     } else if(event->type() == QEvent::GraphicsSceneMouseRelease &&
@@ -198,8 +198,8 @@ bool DiskCreator::sceneEvent(QEvent* event)
         double radius = (pos - disk->position()).norm();
         if(radius == 0) radius = 0.5;
         double inertia = disk->mass() * radius*radius/2.0;
-        _worldModel->setProperty(_item, "radius", QVariant::fromValue(radius));
-        _worldModel->setProperty(_item, "inertia", QVariant::fromValue(inertia));
+        _worldModel->setProperty(_item, QStringLiteral("radius"), QVariant::fromValue(radius));
+        _worldModel->setProperty(_item, QStringLiteral("inertia"), QVariant::fromValue(inertia));
         _worldModel->endMacro();
 
         showMessage(MessageFrame::Information,
@@ -225,7 +225,7 @@ StepCore::Vector2d DiskVertexHandlerGraphicsItem::value()
 
 void DiskVertexHandlerGraphicsItem::setValue(const StepCore::Vector2d& value)
 {
-    _worldModel->setProperty(_item, "radius", value.norm());
+    _worldModel->setProperty(_item, QStringLiteral("radius"), value.norm());
 }
 
 DiskGraphicsItem::DiskGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
@@ -304,8 +304,8 @@ bool BoxCreator::sceneEvent(QEvent* event)
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
         _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
-        _worldModel->setProperty(_item, "position", vpos);
-        _worldModel->setProperty(_item, "size", QVariant::fromValue(StepCore::Vector2d::Zero().eval()));
+        _worldModel->setProperty(_item, QStringLiteral("position"), vpos);
+        _worldModel->setProperty(_item, QStringLiteral("size"), QVariant::fromValue(StepCore::Vector2d::Zero().eval()));
         _worldModel->addItem(_item);
         _worldModel->selectionModel()->setCurrentIndex(_worldModel->objectIndex(_item),
                                                     QItemSelectionModel::ClearAndSelect);
@@ -322,8 +322,8 @@ bool BoxCreator::sceneEvent(QEvent* event)
         StepCore::Vector2d pos = StepGraphicsItem::pointToVector(mouseEvent->scenePos());
         StepCore::Vector2d position = (_topLeft + pos) / 2.0;
         StepCore::Vector2d size = _topLeft - pos;
-        _worldModel->setProperty(_item, "position", QVariant::fromValue(position));
-        _worldModel->setProperty(_item, "size", QVariant::fromValue(size));
+        _worldModel->setProperty(_item, QStringLiteral("position"), QVariant::fromValue(position));
+        _worldModel->setProperty(_item, QStringLiteral("size"), QVariant::fromValue(size));
         return true;
 
     } else if(event->type() == QEvent::GraphicsSceneMouseRelease &&
@@ -336,9 +336,9 @@ bool BoxCreator::sceneEvent(QEvent* event)
         StepCore::Vector2d size = _topLeft - pos;
         if(size[0] == 0 && size[1] == 0) { size[0] = size[1] = 1; }
         double inertia = box->mass() * (size[0]*size[0] + size[1]*size[1]) / 12.0;
-        _worldModel->setProperty(_item, "position", QVariant::fromValue(position));
-        _worldModel->setProperty(_item, "size", QVariant::fromValue(size));
-        _worldModel->setProperty(_item, "inertia", QVariant::fromValue(inertia));
+        _worldModel->setProperty(_item, QStringLiteral("position"), QVariant::fromValue(position));
+        _worldModel->setProperty(_item, QStringLiteral("size"), QVariant::fromValue(size));
+        _worldModel->setProperty(_item, QStringLiteral("inertia"), QVariant::fromValue(inertia));
         _worldModel->endMacro();
 
         showMessage(MessageFrame::Information,
@@ -390,8 +390,8 @@ void PolygonCreator::fixCenterOfMass()
     }
 
     for(i=0; i<v.size(); ++i) v[i] -= center;
-    _worldModel->setProperty(_item, "position", QVariant::fromValue((position + center).eval()));
-    _worldModel->setProperty(_item, "vertexes", QVariant::fromValue(v));
+    _worldModel->setProperty(_item, QStringLiteral("position"), QVariant::fromValue((position + center).eval()));
+    _worldModel->setProperty(_item, QStringLiteral("vertexes"), QVariant::fromValue(v));
 }
 
 void PolygonCreator::fixInertia()
@@ -429,7 +429,7 @@ void PolygonCreator::fixInertia()
     }
 
     inertia = fabs(inertia * mass); // 1 = 1m XXX XXX XXX
-    _worldModel->setProperty(_item, "inertia", QVariant::fromValue(inertia));
+    _worldModel->setProperty(_item, QStringLiteral("inertia"), QVariant::fromValue(inertia));
 }
 
 void PolygonCreator::start()
@@ -449,8 +449,8 @@ bool PolygonCreator::sceneEvent(QEvent* event)
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
         _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
-        _worldModel->setProperty(_item, "position", vpos);
-        _worldModel->setProperty(_item, "vertexes", QString("(0,0)"));
+        _worldModel->setProperty(_item, QStringLiteral("position"), vpos);
+        _worldModel->setProperty(_item, QStringLiteral("vertexes"), QStringLiteral("(0,0)"));
         _worldModel->addItem(_item);
         _worldModel->selectionModel()->setCurrentIndex(_worldModel->objectIndex(_item),
                                                     QItemSelectionModel::ClearAndSelect);
@@ -469,19 +469,19 @@ bool PolygonCreator::sceneEvent(QEvent* event)
 
         _worldModel->simulationPause();
         // XXX: don't use strings !
-        QString vertexes = _item->metaObject()->property("vertexes")->readString(_item).section(',', 0, -3);
+        QString vertexes = _item->metaObject()->property(QStringLiteral("vertexes"))->readString(_item).section(',', 0, -3);
         if(vertexes.isEmpty()) {
-            _worldModel->setProperty(_item, "position", QVariant::fromValue(v));
-            vertexes = QString("(0,0)"); v.setZero();
+            _worldModel->setProperty(_item, QStringLiteral("position"), QVariant::fromValue(v));
+            vertexes = QStringLiteral("(0,0)"); v.setZero();
         } else {
             v -= static_cast<StepCore::Polygon*>(_item)->position();
-            vertexes += QString(",(%1,%2)").arg(v[0]).arg(v[1]);
-            _worldModel->setProperty(_item, "vertexes", vertexes);
+            vertexes += QStringLiteral(",(%1,%2)").arg(v[0]).arg(v[1]);
+            _worldModel->setProperty(_item, QStringLiteral("vertexes"), vertexes);
         }
 
         if(event->type() == QEvent::GraphicsSceneMouseRelease) {
-            vertexes += QString(",(%1,%2)").arg(v[0]).arg(v[1]);
-            _worldModel->setProperty(_item, "vertexes", vertexes);
+            vertexes += QStringLiteral(",(%1,%2)").arg(v[0]).arg(v[1]);
+            _worldModel->setProperty(_item, QStringLiteral("vertexes"), vertexes);
             showMessage(MessageFrame::Information,
                 i18n("Click on the scene to add new vertex or press Enter to finish"));
         }
@@ -571,14 +571,14 @@ void BoxVertexHandlerGraphicsItem::setValue(const StepCore::Vector2d& value)
             newPos[1] = oCorner[1]; newSize[1] = 0;
             _vertexNum ^= 2;
         }
-        _worldModel->setProperty(_item, "position", QVariant::fromValue(newPos));
-        _worldModel->setProperty(_item, "size", QVariant::fromValue(newSize));
+        _worldModel->setProperty(_item, QStringLiteral("position"), QVariant::fromValue(newPos));
+        _worldModel->setProperty(_item, QStringLiteral("size"), QVariant::fromValue(newSize));
         setValue(value);
         return;
     }
 
-    _worldModel->setProperty(_item, "position", QVariant::fromValue(newPos));
-    _worldModel->setProperty(_item, "size", QVariant::fromValue(newSize));
+    _worldModel->setProperty(_item, QStringLiteral("position"), QVariant::fromValue(newPos));
+    _worldModel->setProperty(_item, QStringLiteral("size"), QVariant::fromValue(newSize));
 #if 0
     StepCore::Vector2d delta = box()->vectorWorldToLocal(value) - box()->vertexes()[_vertexNum];
     StepCore::Vector2d newPos = box()->position() + box()->vectorLocalToWorld(delta/2.0);
@@ -673,6 +673,6 @@ void PolygonGraphicsItem::changePolygonVertex(WorldModel* worldModel,
     StepCore::Vector2dList vertexes = static_cast<StepCore::Polygon*>(item)->vertexes();
     Q_ASSERT(vertexNum < (int) vertexes.size());
     vertexes[vertexNum] = value;
-    worldModel->setProperty(item, "vertexes", QVariant::fromValue(vertexes));
+    worldModel->setProperty(item, QStringLiteral("vertexes"), QVariant::fromValue(vertexes));
 }
 
