@@ -31,15 +31,11 @@
 namespace StepCore {
     class Object;
     class Item;
-    class Particle;
-    class Spring;
     class MetaProperty;
 }
 class WorldModel;
 //class WorldScene;
-class QEvent;
 class QTimer;
-class KActionCollection;
 
 /////////////////////////////////////////////////////////////////////////////////////////
 
